from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCampaignErrorEnum(proto.Message):
    class KeywordPlanCampaignError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_NAME: int
        INVALID_LANGUAGES: int
        INVALID_GEOS: int
        DUPLICATE_NAME: int
        MAX_GEOS_EXCEEDED: int
        MAX_LANGUAGES_EXCEEDED: int



from typing import Any

import proto

__protobuf__: Any

class PromotionExtensionDiscountModifierEnum(proto.Message):
    class PromotionExtensionDiscountModifier(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UP_TO: int



from typing import Any

import proto

__protobuf__: Any

class AdGroupFeedErrorEnum(proto.Message):
    class AdGroupFeedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CANNOT_CREATE_FOR_REMOVED_FEED: int
        ADGROUP_FEED_ALREADY_EXISTS: int
        CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED: int
        INVALID_PLACEHOLDER_TYPE: int
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE: int
        NO_EXISTING_LOCATION_CUSTOMER_FEED: int



from typing import Any

import proto

__protobuf__: Any

class AdxErrorEnum(proto.Message):
    class AdxError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNSUPPORTED_FEATURE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    change_client_type as change_client_type,
    change_event_resource_type as change_event_resource_type,
)

__protobuf__: Any

class ChangeEvent(proto.Message):
    class ChangedResource(proto.Message):
        ad: Any
        ad_group: Any
        ad_group_criterion: Any
        campaign: Any
        campaign_budget: Any
        ad_group_bid_modifier: Any
        campaign_criterion: Any
        feed: Any
        feed_item: Any
        campaign_feed: Any
        ad_group_feed: Any
        ad_group_ad: Any
    resource_name: Any
    change_date_time: Any
    change_resource_type: Any
    change_resource_name: Any
    client_type: Any
    user_email: Any
    old_resource: Any
    new_resource: Any
    resource_change_operation: Any
    changed_fields: Any
    campaign: Any
    ad_group: Any
    feed: Any
    feed_item: Any



from typing import Any

import proto

__protobuf__: Any

class AdDestinationTypeEnum(proto.Message):
    class AdDestinationType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NOT_APPLICABLE: int
        WEBSITE: int
        APP_DEEP_LINK: int
        APP_STORE: int
        PHONE_CALL: int
        MAP_DIRECTIONS: int
        LOCATION_LISTING: int
        MESSAGE: int
        LEAD_FORM: int
        YOUTUBE: int
        UNMODELED_FOR_CONVERSIONS: int



from .base import (
    AdGroupAdAssetViewServiceTransport as AdGroupAdAssetViewServiceTransport,
)
from .grpc import (
    AdGroupAdAssetViewServiceGrpcTransport as AdGroupAdAssetViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ClickTypeEnum(proto.Message):
    class ClickType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APP_DEEPLINK: int
        BREADCRUMBS: int
        BROADBAND_PLAN: int
        CALL_TRACKING: int
        CALLS: int
        CLICK_ON_ENGAGEMENT_AD: int
        GET_DIRECTIONS: int
        LOCATION_EXPANSION: int
        LOCATION_FORMAT_CALL: int
        LOCATION_FORMAT_DIRECTIONS: int
        LOCATION_FORMAT_IMAGE: int
        LOCATION_FORMAT_LANDING_PAGE: int
        LOCATION_FORMAT_MAP: int
        LOCATION_FORMAT_STORE_INFO: int
        LOCATION_FORMAT_TEXT: int
        MOBILE_CALL_TRACKING: int
        OFFER_PRINTS: int
        OTHER: int
        PRODUCT_EXTENSION_CLICKS: int
        PRODUCT_LISTING_AD_CLICKS: int
        SITELINKS: int
        STORE_LOCATOR: int
        URL_CLICKS: int
        VIDEO_APP_STORE_CLICKS: int
        VIDEO_CALL_TO_ACTION_CLICKS: int
        VIDEO_CARD_ACTION_HEADLINE_CLICKS: int
        VIDEO_END_CAP_CLICKS: int
        VIDEO_WEBSITE_CLICKS: int
        VISUAL_SITELINKS: int
        WIRELESS_PLAN: int
        PRODUCT_LISTING_AD_LOCAL: int
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL: int
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE: int
        PRODUCT_LISTING_ADS_COUPON: int
        PRODUCT_LISTING_AD_TRANSACTABLE: int
        PRODUCT_AD_APP_DEEPLINK: int
        SHOWCASE_AD_CATEGORY_LINK: int
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK: int
        SHOWCASE_AD_ONLINE_PRODUCT_LINK: int
        SHOWCASE_AD_LOCAL_PRODUCT_LINK: int
        PROMOTION_EXTENSION: int
        SWIPEABLE_GALLERY_AD_HEADLINE: int
        SWIPEABLE_GALLERY_AD_SWIPES: int
        SWIPEABLE_GALLERY_AD_SEE_MORE: int
        SWIPEABLE_GALLERY_AD_SITELINK_ONE: int
        SWIPEABLE_GALLERY_AD_SITELINK_TWO: int
        SWIPEABLE_GALLERY_AD_SITELINK_THREE: int
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR: int
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE: int
        HOTEL_PRICE: int
        PRICE_EXTENSION: int
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION: int
        SHOPPING_COMPARISON_LISTING: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import keyword_plan
from google.ads.googleads.v8.services.types import keyword_plan_service

class KeywordPlanServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def get_keyword_plan(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.GetKeywordPlanRequest], keyword_plan.KeywordPlan
    ]: ...
    @property
    def mutate_keyword_plans(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.MutateKeywordPlansRequest],
        keyword_plan_service.MutateKeywordPlansResponse,
    ]: ...
    @property
    def generate_forecast_curve(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.GenerateForecastCurveRequest],
        keyword_plan_service.GenerateForecastCurveResponse,
    ]: ...
    @property
    def generate_forecast_time_series(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.GenerateForecastTimeSeriesRequest],
        keyword_plan_service.GenerateForecastTimeSeriesResponse,
    ]: ...
    @property
    def generate_forecast_metrics(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.GenerateForecastMetricsRequest],
        keyword_plan_service.GenerateForecastMetricsResponse,
    ]: ...
    @property
    def generate_historical_metrics(
        self,
    ) -> typing.Callable[
        [keyword_plan_service.GenerateHistoricalMetricsRequest],
        keyword_plan_service.GenerateHistoricalMetricsResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class PolicyTopicEvidenceDestinationMismatchUrlTypeEnum(proto.Message):
    class PolicyTopicEvidenceDestinationMismatchUrlType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DISPLAY_URL: int
        FINAL_URL: int
        FINAL_MOBILE_URL: int
        TRACKING_URL: int
        MOBILE_TRACKING_URL: int



from typing import Any

import proto

__protobuf__: Any

class DataDrivenModelStatusEnum(proto.Message):
    class DataDrivenModelStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AVAILABLE: int
        STALE: int
        EXPIRED: int
        NEVER_GENERATED: int



from typing import Any

import proto

__protobuf__: Any

class BillingSetupErrorEnum(proto.Message):
    class BillingSetupError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_USE_EXISTING_AND_NEW_ACCOUNT: int
        CANNOT_REMOVE_STARTED_BILLING_SETUP: int
        CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT: int
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS: int
        INVALID_PAYMENTS_ACCOUNT: int
        BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY: int
        INVALID_START_TIME_TYPE: int
        THIRD_PARTY_ALREADY_HAS_BILLING: int
        BILLING_SETUP_IN_PROGRESS: int
        NO_SIGNUP_PERMISSION: int
        CHANGE_OF_BILL_TO_IN_PROGRESS: int
        PAYMENTS_PROFILE_NOT_FOUND: int
        PAYMENTS_ACCOUNT_NOT_FOUND: int
        PAYMENTS_PROFILE_INELIGIBLE: int
        PAYMENTS_ACCOUNT_INELIGIBLE: int
        CUSTOMER_NEEDS_INTERNAL_APPROVAL: int
        PAYMENTS_ACCOUNT_INELIGIBLE_CURRENCY_CODE_MISMATCH: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import criteria as criteria

__protobuf__: Any

class AdGroupBidModifier(proto.Message):
    resource_name: Any
    ad_group: Any
    criterion_id: Any
    bid_modifier: Any
    base_ad_group: Any
    bid_modifier_source: Any
    hotel_date_selection_type: Any
    hotel_advance_booking_window: Any
    hotel_length_of_stay: Any
    hotel_check_in_day: Any
    device: Any
    preferred_content: Any
    hotel_check_in_date_range: Any



from typing import Any

import proto

__protobuf__: Any

class AdGroupAdRotationModeEnum(proto.Message):
    class AdGroupAdRotationMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPTIMIZE: int
        ROTATE_FOREVER: int



from typing import Any

import proto

__protobuf__: Any

class BudgetDeliveryMethodEnum(proto.Message):
    class BudgetDeliveryMethod(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STANDARD: int
        ACCELERATED: int



from typing import Any

import proto

__protobuf__: Any

class AppCampaignAppStoreEnum(proto.Message):
    class AppCampaignAppStore(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPLE_APP_STORE: int
        GOOGLE_APP_STORE: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import extensions as extensions
from google.ads.googleads.v7.enums.types import keyword_match_type as keyword_match_type

__protobuf__: Any

class GetRecommendationRequest(proto.Message):
    resource_name: Any

class ApplyRecommendationRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any

class ApplyRecommendationOperation(proto.Message):
    class CampaignBudgetParameters(proto.Message):
        new_budget_amount_micros: Any
    class TextAdParameters(proto.Message):
        ad: Any
    class KeywordParameters(proto.Message):
        ad_group: Any
        match_type: Any
        cpc_bid_micros: Any
    class TargetCpaOptInParameters(proto.Message):
        target_cpa_micros: Any
        new_campaign_budget_amount_micros: Any
    class TargetRoasOptInParameters(proto.Message):
        target_roas: Any
        new_campaign_budget_amount_micros: Any
    class CalloutExtensionParameters(proto.Message):
        callout_extensions: Any
    class CallExtensionParameters(proto.Message):
        call_extensions: Any
    class SitelinkExtensionParameters(proto.Message):
        sitelink_extensions: Any
    class MoveUnusedBudgetParameters(proto.Message):
        budget_micros_to_move: Any
    class ResponsiveSearchAdParameters(proto.Message):
        ad: Any
    resource_name: Any
    campaign_budget: Any
    text_ad: Any
    keyword: Any
    target_cpa_opt_in: Any
    target_roas_opt_in: Any
    callout_extension: Any
    call_extension: Any
    sitelink_extension: Any
    move_unused_budget: Any
    responsive_search_ad: Any

class ApplyRecommendationResponse(proto.Message):
    results: Any
    partial_failure_error: Any

class ApplyRecommendationResult(proto.Message):
    resource_name: Any

class DismissRecommendationRequest(proto.Message):
    class DismissRecommendationOperation(proto.Message):
        resource_name: Any
    customer_id: Any
    operations: Any
    partial_failure: Any

class DismissRecommendationResponse(proto.Message):
    class DismissRecommendationResult(proto.Message):
        resource_name: Any
    results: Any
    partial_failure_error: Any



from typing import Any

import proto

__protobuf__: Any

class CustomInterestErrorEnum(proto.Message):
    class CustomInterestError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NAME_ALREADY_USED: int
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE: int
        TYPE_AND_PARAMETER_NOT_FOUND: int
        TYPE_AND_PARAMETER_ALREADY_EXISTED: int
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE: int
        CANNOT_REMOVE_WHILE_IN_USE: int
        CANNOT_CHANGE_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class DateRangeErrorEnum(proto.Message):
    class DateRangeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_DATE: int
        START_DATE_AFTER_END_DATE: int
        CANNOT_SET_DATE_TO_PAST: int
        AFTER_MAXIMUM_ALLOWABLE_DATE: int
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED: int



from .base import (
    AdGroupCriterionSimulationServiceTransport as AdGroupCriterionSimulationServiceTransport,
)
from .grpc import (
    AdGroupCriterionSimulationServiceGrpcTransport as AdGroupCriterionSimulationServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class SizeLimitErrorEnum(proto.Message):
    class SizeLimitError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REQUEST_SIZE_LIMIT_EXCEEDED: int
        RESPONSE_SIZE_LIMIT_EXCEEDED: int



from typing import Any

import proto

__protobuf__: Any

class ThirdPartyAppAnalyticsLinkErrorEnum(proto.Message):
    class ThirdPartyAppAnalyticsLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_ANALYTICS_PROVIDER_ID: int
        INVALID_MOBILE_APP_ID: int
        MOBILE_APP_IS_NOT_ENABLED: int
        CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK: int



from typing import Any

import proto

__protobuf__: Any

class UserListMembershipStatusEnum(proto.Message):
    class UserListMembershipStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPEN: int
        CLOSED: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1, operations_v1
from google.auth import credentials
from google.longrunning import operations_pb2 as operations

from google.ads.googleads.v7.resources.types import campaign_draft
from google.ads.googleads.v7.services.types import campaign_draft_service

class CampaignDraftServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def operations_client(self) -> operations_v1.OperationsClient: ...
    @property
    def get_campaign_draft(
        self,
    ) -> typing.Callable[
        [campaign_draft_service.GetCampaignDraftRequest], campaign_draft.CampaignDraft
    ]: ...
    @property
    def mutate_campaign_drafts(
        self,
    ) -> typing.Callable[
        [campaign_draft_service.MutateCampaignDraftsRequest],
        campaign_draft_service.MutateCampaignDraftsResponse,
    ]: ...
    @property
    def promote_campaign_draft(
        self,
    ) -> typing.Callable[
        [campaign_draft_service.PromoteCampaignDraftRequest], operations.Operation
    ]: ...
    @property
    def list_campaign_draft_async_errors(
        self,
    ) -> typing.Callable[
        [campaign_draft_service.ListCampaignDraftAsyncErrorsRequest],
        campaign_draft_service.ListCampaignDraftAsyncErrorsResponse,
    ]: ...



from typing import Any, Dict, Optional, Sequence, Tuple, Type, Union

from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    operation,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.resources.types import (
    campaign_experiment,
    campaign_experiment as gagr_campaign_experiment,
)
from google.ads.googleads.v8.services.services.campaign_experiment_service import pagers
from google.ads.googleads.v8.services.types import campaign_experiment_service

from .transports.base import CampaignExperimentServiceTransport

class CampaignExperimentServiceClientMeta(type):
    def get_transport_class(
        cls, label: str = ...
    ) -> Type[CampaignExperimentServiceTransport]: ...

class CampaignExperimentServiceClient(metaclass=CampaignExperimentServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Any
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json: Any
    @property
    def transport(self) -> CampaignExperimentServiceTransport: ...
    @staticmethod
    def campaign_path(customer_id: str, campaign_id: str) -> str: ...
    @staticmethod
    def parse_campaign_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_draft_path(
        customer_id: str, base_campaign_id: str, draft_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_draft_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def campaign_experiment_path(
        customer_id: str, campaign_experiment_id: str
    ) -> str: ...
    @staticmethod
    def parse_campaign_experiment_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> Dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> Dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = ...,
        transport: Union[str, CampaignExperimentServiceTransport, None] = ...,
        client_options: Optional[client_options_lib.ClientOptions] = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    def get_campaign_experiment(
        self,
        request: campaign_experiment_service.GetCampaignExperimentRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> campaign_experiment.CampaignExperiment: ...
    def create_campaign_experiment(
        self,
        request: campaign_experiment_service.CreateCampaignExperimentRequest = ...,
        *,
        customer_id: str = ...,
        campaign_experiment: gagr_campaign_experiment.CampaignExperiment = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> operation.Operation: ...
    def mutate_campaign_experiments(
        self,
        request: campaign_experiment_service.MutateCampaignExperimentsRequest = ...,
        *,
        customer_id: str = ...,
        operations: Sequence[
            campaign_experiment_service.CampaignExperimentOperation
        ] = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> campaign_experiment_service.MutateCampaignExperimentsResponse: ...
    def graduate_campaign_experiment(
        self,
        request: campaign_experiment_service.GraduateCampaignExperimentRequest = ...,
        *,
        campaign_experiment: str = ...,
        campaign_budget: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> campaign_experiment_service.GraduateCampaignExperimentResponse: ...
    def promote_campaign_experiment(
        self,
        request: campaign_experiment_service.PromoteCampaignExperimentRequest = ...,
        *,
        campaign_experiment: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> operation.Operation: ...
    def end_campaign_experiment(
        self,
        request: campaign_experiment_service.EndCampaignExperimentRequest = ...,
        *,
        campaign_experiment: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> None: ...
    def list_campaign_experiment_async_errors(
        self,
        request: campaign_experiment_service.ListCampaignExperimentAsyncErrorsRequest = ...,
        *,
        resource_name: str = ...,
        retry: retries.Retry = ...,
        timeout: float = ...,
        metadata: Sequence[Tuple[str, str]] = ...
    ) -> pagers.ListCampaignExperimentAsyncErrorsPager: ...



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    ad_type_infos as ad_type_infos,
    custom_parameter as custom_parameter,
    final_app_url as final_app_url,
    url_collection as url_collection,
)
from google.ads.googleads.v7.enums.types import (
    ad_type as ad_type,
    device as device,
    system_managed_entity_source as system_managed_entity_source,
)

__protobuf__: Any

class Ad(proto.Message):
    resource_name: Any
    id: Any
    final_urls: Any
    final_app_urls: Any
    final_mobile_urls: Any
    tracking_url_template: Any
    final_url_suffix: Any
    url_custom_parameters: Any
    display_url: Any
    type_: Any
    added_by_google_ads: Any
    device_preference: Any
    url_collections: Any
    name: Any
    system_managed_resource_source: Any
    text_ad: Any
    expanded_text_ad: Any
    call_only_ad: Any
    expanded_dynamic_search_ad: Any
    hotel_ad: Any
    shopping_smart_ad: Any
    shopping_product_ad: Any
    gmail_ad: Any
    image_ad: Any
    video_ad: Any
    video_responsive_ad: Any
    responsive_search_ad: Any
    legacy_responsive_display_ad: Any
    app_ad: Any
    legacy_app_install_ad: Any
    responsive_display_ad: Any
    local_ad: Any
    display_upload_ad: Any
    app_engagement_ad: Any
    shopping_comparison_listing_ad: Any



from typing import Any

import proto

__protobuf__: Any

class FeedItemQualityDisapprovalReasonEnum(proto.Message):
    class FeedItemQualityDisapprovalReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRICE_TABLE_REPETITIVE_HEADERS: int
        PRICE_TABLE_REPETITIVE_DESCRIPTION: int
        PRICE_TABLE_INCONSISTENT_ROWS: int
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS: int
        PRICE_UNSUPPORTED_LANGUAGE: int
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH: int
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT: int
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT: int
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT: int
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE: int
        PRICE_TABLE_ROW_UNRATEABLE: int
        PRICE_TABLE_ROW_PRICE_INVALID: int
        PRICE_TABLE_ROW_URL_INVALID: int
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE: int
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED: int
        STRUCTURED_SNIPPETS_REPEATED_VALUES: int
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES: int
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetCampaignDraftRequest(proto.Message):
    resource_name: Any

class MutateCampaignDraftsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class PromoteCampaignDraftRequest(proto.Message):
    campaign_draft: Any
    validate_only: Any

class CampaignDraftOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateCampaignDraftsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCampaignDraftResult(proto.Message):
    resource_name: Any
    campaign_draft: Any

class ListCampaignDraftAsyncErrorsRequest(proto.Message):
    resource_name: Any
    page_token: Any
    page_size: Any

class ListCampaignDraftAsyncErrorsResponse(proto.Message):
    @property
    def raw_page(self): ...
    errors: Any
    next_page_token: Any



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCampaign(proto.Message):
    resource_name: Any
    keyword_plan: Any
    id: Any
    name: Any
    language_constants: Any
    keyword_plan_network: Any
    cpc_bid_micros: Any
    geo_targets: Any

class KeywordPlanGeoTarget(proto.Message):
    geo_target_constant: Any



from typing import Any

import proto

__protobuf__: Any

class CampaignDraftStatusEnum(proto.Message):
    class CampaignDraftStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PROPOSED: int
        REMOVED: int
        PROMOTING: int
        PROMOTED: int
        PROMOTE_FAILED: int



from typing import Any

import proto

__protobuf__: Any

class AdSharingErrorEnum(proto.Message):
    class AdSharingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP_ALREADY_CONTAINS_AD: int
        INCOMPATIBLE_AD_UNDER_AD_GROUP: int
        CANNOT_SHARE_INACTIVE_AD: int



from typing import Any

import proto

__protobuf__: Any

class NewResourceCreationErrorEnum(proto.Message):
    class NewResourceCreationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_SET_ID_FOR_CREATE: int
        DUPLICATE_TEMP_IDS: int
        TEMP_ID_RESOURCE_HAD_ERRORS: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    affiliate_location_feed_relationship_type as affiliate_location_feed_relationship_type,
    feed_attribute_type as feed_attribute_type,
    feed_origin as feed_origin,
    feed_status as feed_status,
)

__protobuf__: Any

class Feed(proto.Message):
    class PlacesLocationFeedData(proto.Message):
        class OAuthInfo(proto.Message):
            http_method: Any
            http_request_url: Any
            http_authorization_header: Any
        oauth_info: Any
        email_address: Any
        business_account_id: Any
        business_name_filter: Any
        category_filters: Any
        label_filters: Any
    class AffiliateLocationFeedData(proto.Message):
        chain_ids: Any
        relationship_type: Any
    resource_name: Any
    id: Any
    name: Any
    attributes: Any
    attribute_operations: Any
    origin: Any
    status: Any
    places_location_feed_data: Any
    affiliate_location_feed_data: Any

class FeedAttribute(proto.Message):
    id: Any
    name: Any
    type_: Any
    is_part_of_key: Any

class FeedAttributeOperation(proto.Message):
    class Operator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADD: int
    operator: Any
    value: Any



from typing import Any

import proto

__protobuf__: Any

class CustomInterestMemberTypeEnum(proto.Message):
    class CustomInterestMemberType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD: int
        URL: int



from typing import Any

import proto

__protobuf__: Any

class PositiveGeoTargetTypeEnum(proto.Message):
    class PositiveGeoTargetType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRESENCE_OR_INTEREST: int
        SEARCH_INTEREST: int
        PRESENCE: int



from typing import Any

import proto

__protobuf__: Any

class FieldErrorEnum(proto.Message):
    class FieldError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        REQUIRED: int
        IMMUTABLE_FIELD: int
        INVALID_VALUE: int
        VALUE_MUST_BE_UNSET: int
        REQUIRED_NONEMPTY_LIST: int
        FIELD_CANNOT_BE_CLEARED: int
        BLOCKED_VALUE: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import asset_policy as asset_policy
from google.ads.googleads.v8.enums.types import (
    served_asset_field_type as served_asset_field_type,
)

__protobuf__: Any

class AdTextAsset(proto.Message):
    text: Any
    pinned_field: Any
    asset_performance_label: Any
    policy_summary_info: Any

class AdImageAsset(proto.Message):
    asset: Any

class AdVideoAsset(proto.Message):
    asset: Any

class AdMediaBundleAsset(proto.Message):
    asset: Any



from typing import Any

import proto

__protobuf__: Any

class CampaignExperimentTypeEnum(proto.Message):
    class CampaignExperimentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BASE: int
        DRAFT: int
        EXPERIMENT: int



from typing import Any

import proto

__protobuf__: Any

class VanityPharmaDisplayUrlModeEnum(proto.Message):
    class VanityPharmaDisplayUrlMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MANUFACTURER_WEBSITE_URL: int
        WEBSITE_DESCRIPTION: int



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import customer_label as customer_label

__protobuf__: Any

class GetCustomerLabelRequest(proto.Message):
    resource_name: Any

class MutateCustomerLabelsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class CustomerLabelOperation(proto.Message):
    create: Any
    remove: Any

class MutateCustomerLabelsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCustomerLabelResult(proto.Message):
    resource_name: Any



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2

from google.ads.googleads.v8.resources.types import custom_audience as custom_audience

__protobuf__: Any

class GetCustomAudienceRequest(proto.Message):
    resource_name: Any

class MutateCustomAudiencesRequest(proto.Message):
    customer_id: Any
    operations: Any
    validate_only: Any

class CustomAudienceOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateCustomAudiencesResponse(proto.Message):
    results: Any

class MutateCustomAudienceResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class PromotionExtensionOccasionEnum(proto.Message):
    class PromotionExtensionOccasion(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NEW_YEARS: int
        CHINESE_NEW_YEAR: int
        VALENTINES_DAY: int
        EASTER: int
        MOTHERS_DAY: int
        FATHERS_DAY: int
        LABOR_DAY: int
        BACK_TO_SCHOOL: int
        HALLOWEEN: int
        BLACK_FRIDAY: int
        CYBER_MONDAY: int
        CHRISTMAS: int
        BOXING_DAY: int
        INDEPENDENCE_DAY: int
        NATIONAL_DAY: int
        END_OF_SEASON: int
        WINTER_SALE: int
        SUMMER_SALE: int
        FALL_SALE: int
        SPRING_SALE: int
        RAMADAN: int
        EID_AL_FITR: int
        EID_AL_ADHA: int
        SINGLES_DAY: int
        WOMENS_DAY: int
        HOLI: int
        PARENTS_DAY: int
        ST_NICHOLAS_DAY: int
        CARNIVAL: int
        EPIPHANY: int
        ROSH_HASHANAH: int
        PASSOVER: int
        HANUKKAH: int
        DIWALI: int
        NAVRATRI: int
        SONGKRAN: int
        YEAR_END_GIFT: int



from typing import Any

import proto

__protobuf__: Any

class LinkedAccountTypeEnum(proto.Message):
    class LinkedAccountType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        THIRD_PARTY_APP_ANALYTICS: int
        DATA_PARTNER: int
        GOOGLE_ADS: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    product_bidding_category_level as product_bidding_category_level,
    product_bidding_category_status as product_bidding_category_status,
)

__protobuf__: Any

class ProductBiddingCategoryConstant(proto.Message):
    resource_name: Any
    id: Any
    country_code: Any
    product_bidding_category_constant_parent: Any
    level: Any
    status: Any
    language_code: Any
    localized_name: Any



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import feed_item_set as feed_item_set

__protobuf__: Any

class GetFeedItemSetRequest(proto.Message):
    resource_name: Any

class MutateFeedItemSetsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class FeedItemSetOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateFeedItemSetsResponse(proto.Message):
    results: Any

class MutateFeedItemSetResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class RecommendationTypeEnum(proto.Message):
    class RecommendationType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_BUDGET: int
        KEYWORD: int
        TEXT_AD: int
        TARGET_CPA_OPT_IN: int
        MAXIMIZE_CONVERSIONS_OPT_IN: int
        ENHANCED_CPC_OPT_IN: int
        SEARCH_PARTNERS_OPT_IN: int
        MAXIMIZE_CLICKS_OPT_IN: int
        OPTIMIZE_AD_ROTATION: int
        CALLOUT_EXTENSION: int
        SITELINK_EXTENSION: int
        CALL_EXTENSION: int
        KEYWORD_MATCH_TYPE: int
        MOVE_UNUSED_BUDGET: int
        FORECASTING_CAMPAIGN_BUDGET: int
        TARGET_ROAS_OPT_IN: int
        RESPONSIVE_SEARCH_AD: int
        MARGINAL_ROI_CAMPAIGN_BUDGET: int



from typing import Any

import proto

__protobuf__: Any

class GetThirdPartyAppAnalyticsLinkRequest(proto.Message):
    resource_name: Any

class RegenerateShareableLinkIdRequest(proto.Message):
    resource_name: Any

class RegenerateShareableLinkIdResponse(proto.Message): ...



from typing import Any

import proto

__protobuf__: Any

class OperationAccessDeniedErrorEnum(proto.Message):
    class OperationAccessDeniedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACTION_NOT_PERMITTED: int
        CREATE_OPERATION_NOT_PERMITTED: int
        REMOVE_OPERATION_NOT_PERMITTED: int
        UPDATE_OPERATION_NOT_PERMITTED: int
        MUTATE_ACTION_NOT_PERMITTED_FOR_CLIENT: int
        OPERATION_NOT_PERMITTED_FOR_CAMPAIGN_TYPE: int
        CREATE_AS_REMOVED_NOT_PERMITTED: int
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE: int
        OPERATION_NOT_PERMITTED_FOR_AD_GROUP_TYPE: int
        MUTATE_NOT_PERMITTED_FOR_CUSTOMER: int



from typing import Any

import proto

__protobuf__: Any

class MediaTypeEnum(proto.Message):
    class MediaType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        IMAGE: int
        ICON: int
        MEDIA_BUNDLE: int
        AUDIO: int
        VIDEO: int
        DYNAMIC_IMAGE: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAggregateMetricTypeEnum(proto.Message):
    class KeywordPlanAggregateMetricType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DEVICE: int



from typing import Any

import proto

__protobuf__: Any

class AssetTypeEnum(proto.Message):
    class AssetType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YOUTUBE_VIDEO: int
        MEDIA_BUNDLE: int
        IMAGE: int
        TEXT: int
        LEAD_FORM: int
        BOOK_ON_GOOGLE: int
        PROMOTION: int
        CALLOUT: int
        STRUCTURED_SNIPPET: int
        SITELINK: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    age_range_type as age_range_type,
    app_payment_model_type as app_payment_model_type,
    content_label_type as content_label_type,
    device as device,
    gender_type as gender_type,
    hotel_date_selection_type as hotel_date_selection_type,
    income_range_type as income_range_type,
    interaction_type as interaction_type,
    keyword_match_type as keyword_match_type,
    listing_group_type as listing_group_type,
    location_group_radius_units as location_group_radius_units,
    minute_of_hour as minute_of_hour,
    parental_status_type as parental_status_type,
    preferred_content_type as preferred_content_type,
    product_bidding_category_level as product_bidding_category_level,
    product_custom_attribute_index as product_custom_attribute_index,
    product_type_level as product_type_level,
    proximity_radius_units as proximity_radius_units,
    webpage_condition_operand as webpage_condition_operand,
    webpage_condition_operator as webpage_condition_operator,
)

__protobuf__: Any

class KeywordInfo(proto.Message):
    text: Any
    match_type: Any

class PlacementInfo(proto.Message):
    url: Any

class MobileAppCategoryInfo(proto.Message):
    mobile_app_category_constant: Any

class MobileApplicationInfo(proto.Message):
    app_id: Any
    name: Any

class LocationInfo(proto.Message):
    geo_target_constant: Any

class DeviceInfo(proto.Message):
    type_: Any

class PreferredContentInfo(proto.Message):
    type_: Any

class ListingGroupInfo(proto.Message):
    type_: Any
    case_value: Any
    parent_ad_group_criterion: Any

class ListingScopeInfo(proto.Message):
    dimensions: Any

class ListingDimensionInfo(proto.Message):
    hotel_id: Any
    hotel_class: Any
    hotel_country_region: Any
    hotel_state: Any
    hotel_city: Any
    product_bidding_category: Any
    product_brand: Any
    product_channel: Any
    product_channel_exclusivity: Any
    product_condition: Any
    product_custom_attribute: Any
    product_item_id: Any
    product_type: Any
    unknown_listing_dimension: Any

class HotelIdInfo(proto.Message):
    value: Any

class HotelClassInfo(proto.Message):
    value: Any

class HotelCountryRegionInfo(proto.Message):
    country_region_criterion: Any

class HotelStateInfo(proto.Message):
    state_criterion: Any

class HotelCityInfo(proto.Message):
    city_criterion: Any

class ProductBiddingCategoryInfo(proto.Message):
    id: Any
    country_code: Any
    level: Any

class ProductBrandInfo(proto.Message):
    value: Any

class ProductChannelInfo(proto.Message):
    channel: Any

class ProductChannelExclusivityInfo(proto.Message):
    channel_exclusivity: Any

class ProductConditionInfo(proto.Message):
    condition: Any

class ProductCustomAttributeInfo(proto.Message):
    value: Any
    index: Any

class ProductItemIdInfo(proto.Message):
    value: Any

class ProductTypeInfo(proto.Message):
    value: Any
    level: Any

class UnknownListingDimensionInfo(proto.Message): ...

class HotelDateSelectionTypeInfo(proto.Message):
    type_: Any

class HotelAdvanceBookingWindowInfo(proto.Message):
    min_days: Any
    max_days: Any

class HotelLengthOfStayInfo(proto.Message):
    min_nights: Any
    max_nights: Any

class HotelCheckInDateRangeInfo(proto.Message):
    start_date: Any
    end_date: Any

class HotelCheckInDayInfo(proto.Message):
    day_of_week: Any

class InteractionTypeInfo(proto.Message):
    type_: Any

class AdScheduleInfo(proto.Message):
    start_minute: Any
    end_minute: Any
    start_hour: Any
    end_hour: Any
    day_of_week: Any

class AgeRangeInfo(proto.Message):
    type_: Any

class GenderInfo(proto.Message):
    type_: Any

class IncomeRangeInfo(proto.Message):
    type_: Any

class ParentalStatusInfo(proto.Message):
    type_: Any

class YouTubeVideoInfo(proto.Message):
    video_id: Any

class YouTubeChannelInfo(proto.Message):
    channel_id: Any

class UserListInfo(proto.Message):
    user_list: Any

class ProximityInfo(proto.Message):
    geo_point: Any
    radius: Any
    radius_units: Any
    address: Any

class GeoPointInfo(proto.Message):
    longitude_in_micro_degrees: Any
    latitude_in_micro_degrees: Any

class AddressInfo(proto.Message):
    postal_code: Any
    province_code: Any
    country_code: Any
    province_name: Any
    street_address: Any
    street_address2: Any
    city_name: Any

class TopicInfo(proto.Message):
    topic_constant: Any
    path: Any

class LanguageInfo(proto.Message):
    language_constant: Any

class IpBlockInfo(proto.Message):
    ip_address: Any

class ContentLabelInfo(proto.Message):
    type_: Any

class CarrierInfo(proto.Message):
    carrier_constant: Any

class UserInterestInfo(proto.Message):
    user_interest_category: Any

class WebpageInfo(proto.Message):
    criterion_name: Any
    conditions: Any
    coverage_percentage: Any
    sample: Any

class WebpageConditionInfo(proto.Message):
    operand: Any
    operator: Any
    argument: Any

class WebpageSampleInfo(proto.Message):
    sample_urls: Any

class OperatingSystemVersionInfo(proto.Message):
    operating_system_version_constant: Any

class AppPaymentModelInfo(proto.Message):
    type_: Any

class MobileDeviceInfo(proto.Message):
    mobile_device_constant: Any

class CustomAffinityInfo(proto.Message):
    custom_affinity: Any

class CustomIntentInfo(proto.Message):
    custom_intent: Any

class LocationGroupInfo(proto.Message):
    feed: Any
    geo_target_constants: Any
    radius: Any
    radius_units: Any
    feed_item_sets: Any

class CustomAudienceInfo(proto.Message):
    custom_audience: Any

class CombinedAudienceInfo(proto.Message):
    combined_audience: Any

class KeywordThemeInfo(proto.Message):
    keyword_theme_constant: Any
    free_form_keyword_theme: Any



from typing import Any

import proto

__protobuf__: Any

class TargetingSetting(proto.Message):
    target_restrictions: Any
    target_restriction_operations: Any

class TargetRestriction(proto.Message):
    targeting_dimension: Any
    bid_only: Any

class TargetRestrictionOperation(proto.Message):
    class Operator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADD: int
        REMOVE: int
    operator: Any
    value: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    asset_field_type as asset_field_type,
    asset_performance_label as asset_performance_label,
    policy_approval_status as policy_approval_status,
    policy_review_status as policy_review_status,
)

__protobuf__: Any

class AdGroupAdAssetView(proto.Message):
    resource_name: Any
    ad_group_ad: Any
    asset: Any
    field_type: Any
    enabled: Any
    policy_summary: Any
    performance_label: Any

class AdGroupAdAssetPolicySummary(proto.Message):
    policy_topic_entries: Any
    review_status: Any
    approval_status: Any



from typing import Any

import proto

__protobuf__: Any

class CriterionErrorEnum(proto.Message):
    class CriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONCRETE_TYPE_REQUIRED: int
        INVALID_EXCLUDED_CATEGORY: int
        INVALID_KEYWORD_TEXT: int
        KEYWORD_TEXT_TOO_LONG: int
        KEYWORD_HAS_TOO_MANY_WORDS: int
        KEYWORD_HAS_INVALID_CHARS: int
        INVALID_PLACEMENT_URL: int
        INVALID_USER_LIST: int
        INVALID_USER_INTEREST: int
        INVALID_FORMAT_FOR_PLACEMENT_URL: int
        PLACEMENT_URL_IS_TOO_LONG: int
        PLACEMENT_URL_HAS_ILLEGAL_CHAR: int
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE: int
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION: int
        INVALID_TOPIC_PATH: int
        INVALID_YOUTUBE_CHANNEL_ID: int
        INVALID_YOUTUBE_VIDEO_ID: int
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED: int
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED: int
        YOUTUBE_URL_UNSUPPORTED: int
        CANNOT_EXCLUDE_CRITERIA_TYPE: int
        CANNOT_ADD_CRITERIA_TYPE: int
        CANNOT_EXCLUDE_SIMILAR_USER_LIST: int
        CANNOT_ADD_CLOSED_USER_LIST: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS: int
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS: int
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS: int
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE: int
        INVALID_COMBINED_AUDIENCE: int
        INVALID_CUSTOM_AFFINITY: int
        INVALID_CUSTOM_INTENT: int
        INVALID_CUSTOM_AUDIENCE: int
        INVALID_IP_ADDRESS: int
        INVALID_IP_FORMAT: int
        INVALID_MOBILE_APP: int
        INVALID_MOBILE_APP_CATEGORY: int
        INVALID_CRITERION_ID: int
        CANNOT_TARGET_CRITERION: int
        CANNOT_TARGET_OBSOLETE_CRITERION: int
        CRITERION_ID_AND_TYPE_MISMATCH: int
        INVALID_PROXIMITY_RADIUS: int
        INVALID_PROXIMITY_RADIUS_UNITS: int
        INVALID_STREETADDRESS_LENGTH: int
        INVALID_CITYNAME_LENGTH: int
        INVALID_REGIONCODE_LENGTH: int
        INVALID_REGIONNAME_LENGTH: int
        INVALID_POSTALCODE_LENGTH: int
        INVALID_COUNTRY_CODE: int
        INVALID_LATITUDE: int
        INVALID_LONGITUDE: int
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL: int
        INVALID_PROXIMITY_ADDRESS: int
        INVALID_USER_DOMAIN_NAME: int
        CRITERION_PARAMETER_TOO_LONG: int
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP: int
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS: int
        AD_SCHEDULE_INVALID_TIME_INTERVAL: int
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT: int
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS: int
        CANNOT_BID_MODIFY_CRITERION_TYPE: int
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT: int
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION: int
        BID_MODIFIER_ALREADY_EXISTS: int
        FEED_ID_NOT_ALLOWED: int
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE: int
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY: int
        CANNOT_EXCLUDE_CRITERION: int
        CANNOT_REMOVE_CRITERION: int
        INVALID_PRODUCT_BIDDING_CATEGORY: int
        MISSING_SHOPPING_SETTING: int
        INVALID_MATCHING_FUNCTION: int
        LOCATION_FILTER_NOT_ALLOWED: int
        INVALID_FEED_FOR_LOCATION_FILTER: int
        LOCATION_FILTER_INVALID: int
        CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS: int
        INVALID_LOCATION_GROUP_RADIUS: int
        INVALID_LOCATION_GROUP_RADIUS_UNIT: int
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP: int
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION: int
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION: int
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING: int
        INVALID_WEBPAGE_CONDITION: int
        INVALID_WEBPAGE_CONDITION_URL: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY: int
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS: int
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX: int
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX: int
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED: int
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION: int
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP: int
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS: int
        CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS: int
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES: int
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS: int
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED: int
        DUPLICATE_LISTING_DIMENSION_TYPE: int
        DUPLICATE_LISTING_DIMENSION_VALUE: int
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION: int
        INVALID_LISTING_GROUP_HIERARCHY: int
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN: int
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE: int
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS: int
        LISTING_GROUP_ALREADY_EXISTS: int
        LISTING_GROUP_DOES_NOT_EXIST: int
        LISTING_GROUP_CANNOT_BE_REMOVED: int
        INVALID_LISTING_GROUP_TYPE: int
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID: int
        LISTING_SCOPE_TOO_LONG: int
        LISTING_SCOPE_TOO_MANY_DIMENSIONS: int
        LISTING_GROUP_TOO_LONG: int
        LISTING_GROUP_TREE_TOO_DEEP: int
        INVALID_LISTING_DIMENSION: int
        INVALID_LISTING_DIMENSION_TYPE: int
        ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY: int
        CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE: int
        INVALID_COMBINED_AUDIENCE_ID: int
        CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE: int
        HOTEL_CHECK_IN_DATE_RANGE_OVERLAPS_WITH_EXISTING_CRITERION: int
        HOTEL_CHECK_IN_DATE_RANGE_START_DATE_TOO_EARLY: int
        HOTEL_CHECK_IN_DATE_RANGE_END_DATE_TOO_LATE: int
        HOTEL_CHECK_IN_DATE_RANGE_REVERSED: int



from typing import Any

import proto

__protobuf__: Any

class IncomeRangeTypeEnum(proto.Message):
    class IncomeRangeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INCOME_RANGE_0_50: int
        INCOME_RANGE_50_60: int
        INCOME_RANGE_60_70: int
        INCOME_RANGE_70_80: int
        INCOME_RANGE_80_90: int
        INCOME_RANGE_90_UP: int
        INCOME_RANGE_UNDETERMINED: int



from typing import Any

import proto

__protobuf__: Any

class InteractionTypeEnum(proto.Message):
    class InteractionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CALLS: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    target_impression_share_location as target_impression_share_location,
)

__protobuf__: Any

class Commission(proto.Message):
    commission_rate_micros: Any

class EnhancedCpc(proto.Message): ...

class ManualCpc(proto.Message):
    enhanced_cpc_enabled: Any

class ManualCpm(proto.Message): ...
class ManualCpv(proto.Message): ...

class MaximizeConversions(proto.Message):
    target_cpa: Any

class MaximizeConversionValue(proto.Message):
    target_roas: Any

class TargetCpa(proto.Message):
    target_cpa_micros: Any
    cpc_bid_ceiling_micros: Any
    cpc_bid_floor_micros: Any

class TargetCpm(proto.Message): ...

class TargetImpressionShare(proto.Message):
    location: Any
    location_fraction_micros: Any
    cpc_bid_ceiling_micros: Any

class TargetRoas(proto.Message):
    target_roas: Any
    cpc_bid_ceiling_micros: Any
    cpc_bid_floor_micros: Any

class TargetSpend(proto.Message):
    target_spend_micros: Any
    cpc_bid_ceiling_micros: Any

class PercentCpc(proto.Message):
    cpc_bid_ceiling_micros: Any
    enhanced_cpc_enabled: Any



from typing import Any

import proto

__protobuf__: Any

class GetAccountLinkRequest(proto.Message):
    resource_name: Any

class CreateAccountLinkRequest(proto.Message):
    customer_id: Any
    account_link: Any

class CreateAccountLinkResponse(proto.Message):
    resource_name: Any

class MutateAccountLinkRequest(proto.Message):
    customer_id: Any
    operation: Any
    partial_failure: Any
    validate_only: Any

class AccountLinkOperation(proto.Message):
    update_mask: Any
    update: Any
    remove: Any

class MutateAccountLinkResponse(proto.Message):
    result: Any

class MutateAccountLinkResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class CurrencyCodeErrorEnum(proto.Message):
    class CurrencyCodeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNSUPPORTED: int



from typing import Any

import proto

__protobuf__: Any

class BatchJobStatusEnum(proto.Message):
    class BatchJobStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        RUNNING: int
        DONE: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1, operations_v1
from google.auth import credentials
from google.longrunning import operations_pb2 as operations
from google.protobuf import empty_pb2 as empty

from google.ads.googleads.v7.resources.types import campaign_experiment
from google.ads.googleads.v7.services.types import campaign_experiment_service

class CampaignExperimentServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def operations_client(self) -> operations_v1.OperationsClient: ...
    @property
    def get_campaign_experiment(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.GetCampaignExperimentRequest],
        campaign_experiment.CampaignExperiment,
    ]: ...
    @property
    def create_campaign_experiment(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.CreateCampaignExperimentRequest],
        operations.Operation,
    ]: ...
    @property
    def mutate_campaign_experiments(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.MutateCampaignExperimentsRequest],
        campaign_experiment_service.MutateCampaignExperimentsResponse,
    ]: ...
    @property
    def graduate_campaign_experiment(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.GraduateCampaignExperimentRequest],
        campaign_experiment_service.GraduateCampaignExperimentResponse,
    ]: ...
    @property
    def promote_campaign_experiment(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.PromoteCampaignExperimentRequest],
        operations.Operation,
    ]: ...
    @property
    def end_campaign_experiment(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.EndCampaignExperimentRequest], empty.Empty
    ]: ...
    @property
    def list_campaign_experiment_async_errors(
        self,
    ) -> typing.Callable[
        [campaign_experiment_service.ListCampaignExperimentAsyncErrorsRequest],
        campaign_experiment_service.ListCampaignExperimentAsyncErrorsResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class BrandSafetySuitabilityEnum(proto.Message):
    class BrandSafetySuitability(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXPANDED_INVENTORY: int
        STANDARD_INVENTORY: int
        LIMITED_INVENTORY: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import offline_user_data as offline_user_data
from google.ads.googleads.v7.enums.types import (
    offline_user_data_job_failure_reason as offline_user_data_job_failure_reason,
    offline_user_data_job_status as offline_user_data_job_status,
    offline_user_data_job_type as offline_user_data_job_type,
)

__protobuf__: Any

class OfflineUserDataJob(proto.Message):
    resource_name: Any
    id: Any
    external_id: Any
    type_: Any
    status: Any
    failure_reason: Any
    customer_match_user_list_metadata: Any
    store_sales_metadata: Any



from typing import Any

import proto

__protobuf__: Any

class CustomAudienceErrorEnum(proto.Message):
    class CustomAudienceError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NAME_ALREADY_USED: int
        CANNOT_REMOVE_WHILE_IN_USE: int
        RESOURCE_ALREADY_REMOVED: int
        MEMBER_TYPE_AND_PARAMETER_ALREADY_EXISTED: int
        INVALID_MEMBER_TYPE: int
        MEMBER_TYPE_AND_VALUE_DOES_NOT_MATCH: int
        POLICY_VIOLATION: int
        INVALID_TYPE_CHANGE: int



from .base import (
    HotelPerformanceViewServiceTransport as HotelPerformanceViewServiceTransport,
)
from .grpc import (
    HotelPerformanceViewServiceGrpcTransport as HotelPerformanceViewServiceGrpcTransport,
)



from .base import (
    OperatingSystemVersionConstantServiceTransport as OperatingSystemVersionConstantServiceTransport,
)
from .grpc import (
    OperatingSystemVersionConstantServiceGrpcTransport as OperatingSystemVersionConstantServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class SummaryRowSettingEnum(proto.Message):
    class SummaryRowSetting(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NO_SUMMARY_ROW: int
        SUMMARY_ROW_WITH_RESULTS: int
        SUMMARY_ROW_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemSetErrorEnum(proto.Message):
    class FeedItemSetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FEED_ITEM_SET_REMOVED: int
        CANNOT_CLEAR_DYNAMIC_FILTER: int
        CANNOT_CREATE_DYNAMIC_FILTER: int
        INVALID_FEED_TYPE: int
        DUPLICATE_NAME: int
        WRONG_DYNAMIC_FILTER_FOR_FEED_TYPE: int
        DYNAMIC_FILTER_INVALID_CHAIN_IDS: int



from typing import Any

import proto

__protobuf__: Any

class DistinctErrorEnum(proto.Message):
    class DistinctError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_ELEMENT: int
        DUPLICATE_TYPE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    merchant_center_link_status as merchant_center_link_status,
)

__protobuf__: Any

class MerchantCenterLink(proto.Message):
    resource_name: Any
    id: Any
    merchant_center_account_name: Any
    status: Any



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import billing_setup as billing_setup

__protobuf__: Any

class GetBillingSetupRequest(proto.Message):
    resource_name: Any

class MutateBillingSetupRequest(proto.Message):
    customer_id: Any
    operation: Any

class BillingSetupOperation(proto.Message):
    create: Any
    remove: Any

class MutateBillingSetupResponse(proto.Message):
    result: Any

class MutateBillingSetupResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class UserListStringRuleItemOperatorEnum(proto.Message):
    class UserListStringRuleItemOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONTAINS: int
        EQUALS: int
        STARTS_WITH: int
        ENDS_WITH: int
        NOT_EQUALS: int
        NOT_CONTAINS: int
        NOT_STARTS_WITH: int
        NOT_ENDS_WITH: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import batch_job_status as batch_job_status

__protobuf__: Any

class BatchJob(proto.Message):
    class BatchJobMetadata(proto.Message):
        creation_date_time: Any
        start_date_time: Any
        completion_date_time: Any
        estimated_completion_ratio: Any
        operation_count: Any
        executed_operation_count: Any
    resource_name: Any
    id: Any
    next_add_sequence_token: Any
    metadata: Any
    status: Any
    long_running_operation: Any



from typing import Any

import proto

__protobuf__: Any

class AdGroupCriterionErrorEnum(proto.Message):
    class AdGroupCriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST: int
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS: int
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION: int
        TOO_MANY_OPERATIONS: int
        CANT_UPDATE_NEGATIVE: int
        CONCRETE_TYPE_REQUIRED: int
        BID_INCOMPATIBLE_WITH_ADGROUP: int
        CANNOT_TARGET_AND_EXCLUDE: int
        ILLEGAL_URL: int
        INVALID_KEYWORD_TEXT: int
        INVALID_DESTINATION_URL: int
        MISSING_DESTINATION_URL_TAG: int
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM: int
        INVALID_USER_STATUS: int
        CANNOT_ADD_CRITERIA_TYPE: int
        CANNOT_EXCLUDE_CRITERIA_TYPE: int
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE: int
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS: int
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST: int
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST: int
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS: int
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST: int
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS: int
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE: int
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class EducationPlaceholderFieldEnum(proto.Message):
    class EducationPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PROGRAM_ID: int
        LOCATION_ID: int
        PROGRAM_NAME: int
        AREA_OF_STUDY: int
        PROGRAM_DESCRIPTION: int
        SCHOOL_NAME: int
        ADDRESS: int
        THUMBNAIL_IMAGE_URL: int
        ALTERNATIVE_THUMBNAIL_IMAGE_URL: int
        FINAL_URLS: int
        FINAL_MOBILE_URLS: int
        TRACKING_URL: int
        CONTEXTUAL_KEYWORDS: int
        ANDROID_APP_LINK: int
        SIMILAR_PROGRAM_IDS: int
        IOS_APP_LINK: int
        IOS_APP_STORE_ID: int



from typing import Any

import proto

__protobuf__: Any

class CustomerClientLinkErrorEnum(proto.Message):
    class CustomerClientLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER: int
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY: int
        CYCLIC_LINK_NOT_ALLOWED: int
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS: int
        CLIENT_HAS_TOO_MANY_INVITATIONS: int
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS: int
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER: int
        CLIENT_HAS_TOO_MANY_MANAGERS: int



from .base import (
    DetailPlacementViewServiceTransport as DetailPlacementViewServiceTransport,
)
from .grpc import (
    DetailPlacementViewServiceGrpcTransport as DetailPlacementViewServiceGrpcTransport,
)



from typing import Any

import proto

from google.ads.googleads.v7.services.types import (
    ad_group_ad_label_service as ad_group_ad_label_service,
    ad_group_ad_service as ad_group_ad_service,
    ad_group_asset_service as ad_group_asset_service,
    ad_group_bid_modifier_service as ad_group_bid_modifier_service,
    ad_group_criterion_label_service as ad_group_criterion_label_service,
    ad_group_criterion_service as ad_group_criterion_service,
    ad_group_extension_setting_service as ad_group_extension_setting_service,
    ad_group_feed_service as ad_group_feed_service,
    ad_group_label_service as ad_group_label_service,
    ad_group_service as ad_group_service,
    ad_parameter_service as ad_parameter_service,
    ad_service as ad_service,
    asset_service as asset_service,
    bidding_strategy_service as bidding_strategy_service,
    campaign_asset_service as campaign_asset_service,
    campaign_bid_modifier_service as campaign_bid_modifier_service,
    campaign_budget_service as campaign_budget_service,
    campaign_criterion_service as campaign_criterion_service,
    campaign_draft_service as campaign_draft_service,
    campaign_experiment_service as campaign_experiment_service,
    campaign_extension_setting_service as campaign_extension_setting_service,
    campaign_feed_service as campaign_feed_service,
    campaign_label_service as campaign_label_service,
    campaign_service as campaign_service,
    campaign_shared_set_service as campaign_shared_set_service,
    conversion_action_service as conversion_action_service,
    conversion_custom_variable_service as conversion_custom_variable_service,
    customer_asset_service as customer_asset_service,
    customer_extension_setting_service as customer_extension_setting_service,
    customer_feed_service as customer_feed_service,
    customer_label_service as customer_label_service,
    customer_negative_criterion_service as customer_negative_criterion_service,
    customer_service as customer_service,
    extension_feed_item_service as extension_feed_item_service,
    feed_item_service as feed_item_service,
    feed_item_set_link_service as feed_item_set_link_service,
    feed_item_set_service as feed_item_set_service,
    feed_item_target_service as feed_item_target_service,
    feed_mapping_service as feed_mapping_service,
    feed_service as feed_service,
    keyword_plan_ad_group_keyword_service as keyword_plan_ad_group_keyword_service,
    keyword_plan_ad_group_service as keyword_plan_ad_group_service,
    keyword_plan_campaign_keyword_service as keyword_plan_campaign_keyword_service,
    keyword_plan_campaign_service as keyword_plan_campaign_service,
    keyword_plan_service as keyword_plan_service,
    label_service as label_service,
    media_file_service as media_file_service,
    remarketing_action_service as remarketing_action_service,
    shared_criterion_service as shared_criterion_service,
    shared_set_service as shared_set_service,
    user_list_service as user_list_service,
)

__protobuf__: Any

class SearchGoogleAdsRequest(proto.Message):
    customer_id: Any
    query: Any
    page_token: Any
    page_size: Any
    validate_only: Any
    return_total_results_count: Any
    summary_row_setting: Any

class SearchGoogleAdsResponse(proto.Message):
    @property
    def raw_page(self): ...
    results: Any
    next_page_token: Any
    total_results_count: Any
    field_mask: Any
    summary_row: Any

class SearchGoogleAdsStreamRequest(proto.Message):
    customer_id: Any
    query: Any
    summary_row_setting: Any

class SearchGoogleAdsStreamResponse(proto.Message):
    results: Any
    field_mask: Any
    summary_row: Any
    request_id: Any

class GoogleAdsRow(proto.Message):
    account_budget: Any
    account_budget_proposal: Any
    account_link: Any
    ad_group: Any
    ad_group_ad: Any
    ad_group_ad_asset_view: Any
    ad_group_ad_label: Any
    ad_group_asset: Any
    ad_group_audience_view: Any
    ad_group_bid_modifier: Any
    ad_group_criterion: Any
    ad_group_criterion_label: Any
    ad_group_criterion_simulation: Any
    ad_group_extension_setting: Any
    ad_group_feed: Any
    ad_group_label: Any
    ad_group_simulation: Any
    ad_parameter: Any
    age_range_view: Any
    ad_schedule_view: Any
    domain_category: Any
    asset: Any
    batch_job: Any
    bidding_strategy: Any
    bidding_strategy_simulation: Any
    billing_setup: Any
    call_view: Any
    campaign_budget: Any
    campaign: Any
    campaign_asset: Any
    campaign_audience_view: Any
    campaign_bid_modifier: Any
    campaign_criterion: Any
    campaign_criterion_simulation: Any
    campaign_draft: Any
    campaign_experiment: Any
    campaign_extension_setting: Any
    campaign_feed: Any
    campaign_label: Any
    campaign_shared_set: Any
    campaign_simulation: Any
    carrier_constant: Any
    change_event: Any
    change_status: Any
    combined_audience: Any
    conversion_action: Any
    conversion_custom_variable: Any
    click_view: Any
    currency_constant: Any
    custom_audience: Any
    custom_interest: Any
    customer: Any
    customer_asset: Any
    customer_manager_link: Any
    customer_client_link: Any
    customer_client: Any
    customer_extension_setting: Any
    customer_feed: Any
    customer_label: Any
    customer_negative_criterion: Any
    customer_user_access: Any
    customer_user_access_invitation: Any
    detail_placement_view: Any
    display_keyword_view: Any
    distance_view: Any
    dynamic_search_ads_search_term_view: Any
    expanded_landing_page_view: Any
    extension_feed_item: Any
    feed: Any
    feed_item: Any
    feed_item_set: Any
    feed_item_set_link: Any
    feed_item_target: Any
    feed_mapping: Any
    feed_placeholder_view: Any
    gender_view: Any
    geo_target_constant: Any
    geographic_view: Any
    group_placement_view: Any
    hotel_group_view: Any
    hotel_performance_view: Any
    income_range_view: Any
    keyword_view: Any
    keyword_plan: Any
    keyword_plan_campaign: Any
    keyword_plan_campaign_keyword: Any
    keyword_plan_ad_group: Any
    keyword_plan_ad_group_keyword: Any
    label: Any
    landing_page_view: Any
    language_constant: Any
    location_view: Any
    managed_placement_view: Any
    media_file: Any
    mobile_app_category_constant: Any
    mobile_device_constant: Any
    offline_user_data_job: Any
    operating_system_version_constant: Any
    paid_organic_search_term_view: Any
    parental_status_view: Any
    product_bidding_category_constant: Any
    product_group_view: Any
    recommendation: Any
    search_term_view: Any
    shared_criterion: Any
    shared_set: Any
    shopping_performance_view: Any
    third_party_app_analytics_link: Any
    topic_view: Any
    user_interest: Any
    life_event: Any
    user_list: Any
    user_location_view: Any
    remarketing_action: Any
    topic_constant: Any
    video: Any
    webpage_view: Any
    metrics: Any
    segments: Any

class MutateGoogleAdsRequest(proto.Message):
    customer_id: Any
    mutate_operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class MutateGoogleAdsResponse(proto.Message):
    partial_failure_error: Any
    mutate_operation_responses: Any

class MutateOperation(proto.Message):
    ad_group_ad_label_operation: Any
    ad_group_ad_operation: Any
    ad_group_asset_operation: Any
    ad_group_bid_modifier_operation: Any
    ad_group_criterion_label_operation: Any
    ad_group_criterion_operation: Any
    ad_group_extension_setting_operation: Any
    ad_group_feed_operation: Any
    ad_group_label_operation: Any
    ad_group_operation: Any
    ad_operation: Any
    ad_parameter_operation: Any
    asset_operation: Any
    bidding_strategy_operation: Any
    campaign_asset_operation: Any
    campaign_bid_modifier_operation: Any
    campaign_budget_operation: Any
    campaign_criterion_operation: Any
    campaign_draft_operation: Any
    campaign_experiment_operation: Any
    campaign_extension_setting_operation: Any
    campaign_feed_operation: Any
    campaign_label_operation: Any
    campaign_operation: Any
    campaign_shared_set_operation: Any
    conversion_action_operation: Any
    conversion_custom_variable_operation: Any
    customer_asset_operation: Any
    customer_extension_setting_operation: Any
    customer_feed_operation: Any
    customer_label_operation: Any
    customer_negative_criterion_operation: Any
    customer_operation: Any
    extension_feed_item_operation: Any
    feed_item_operation: Any
    feed_item_set_operation: Any
    feed_item_set_link_operation: Any
    feed_item_target_operation: Any
    feed_mapping_operation: Any
    feed_operation: Any
    keyword_plan_ad_group_operation: Any
    keyword_plan_ad_group_keyword_operation: Any
    keyword_plan_campaign_keyword_operation: Any
    keyword_plan_campaign_operation: Any
    keyword_plan_operation: Any
    label_operation: Any
    media_file_operation: Any
    remarketing_action_operation: Any
    shared_criterion_operation: Any
    shared_set_operation: Any
    user_list_operation: Any

class MutateOperationResponse(proto.Message):
    ad_group_ad_label_result: Any
    ad_group_ad_result: Any
    ad_group_asset_result: Any
    ad_group_bid_modifier_result: Any
    ad_group_criterion_label_result: Any
    ad_group_criterion_result: Any
    ad_group_extension_setting_result: Any
    ad_group_feed_result: Any
    ad_group_label_result: Any
    ad_group_result: Any
    ad_parameter_result: Any
    ad_result: Any
    asset_result: Any
    bidding_strategy_result: Any
    campaign_asset_result: Any
    campaign_bid_modifier_result: Any
    campaign_budget_result: Any
    campaign_criterion_result: Any
    campaign_draft_result: Any
    campaign_experiment_result: Any
    campaign_extension_setting_result: Any
    campaign_feed_result: Any
    campaign_label_result: Any
    campaign_result: Any
    campaign_shared_set_result: Any
    conversion_action_result: Any
    conversion_custom_variable_result: Any
    customer_asset_result: Any
    customer_extension_setting_result: Any
    customer_feed_result: Any
    customer_label_result: Any
    customer_negative_criterion_result: Any
    customer_result: Any
    extension_feed_item_result: Any
    feed_item_result: Any
    feed_item_set_result: Any
    feed_item_set_link_result: Any
    feed_item_target_result: Any
    feed_mapping_result: Any
    feed_result: Any
    keyword_plan_ad_group_result: Any
    keyword_plan_campaign_result: Any
    keyword_plan_ad_group_keyword_result: Any
    keyword_plan_campaign_keyword_result: Any
    keyword_plan_result: Any
    label_result: Any
    media_file_result: Any
    remarketing_action_result: Any
    shared_criterion_result: Any
    shared_set_result: Any
    user_list_result: Any



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    extension_setting_device as extension_setting_device,
)

__protobuf__: Any

class CustomerExtensionSetting(proto.Message):
    resource_name: Any
    extension_type: Any
    extension_feed_items: Any
    device: Any



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials

from google.ads.googleads.v7.resources.types import merchant_center_link
from google.ads.googleads.v7.services.types import merchant_center_link_service

class MerchantCenterLinkServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def list_merchant_center_links(
        self,
    ) -> typing.Callable[
        [merchant_center_link_service.ListMerchantCenterLinksRequest],
        merchant_center_link_service.ListMerchantCenterLinksResponse,
    ]: ...
    @property
    def get_merchant_center_link(
        self,
    ) -> typing.Callable[
        [merchant_center_link_service.GetMerchantCenterLinkRequest],
        merchant_center_link.MerchantCenterLink,
    ]: ...
    @property
    def mutate_merchant_center_link(
        self,
    ) -> typing.Callable[
        [merchant_center_link_service.MutateMerchantCenterLinkRequest],
        merchant_center_link_service.MutateMerchantCenterLinkResponse,
    ]: ...



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    campaign_experiment_status as campaign_experiment_status,
    campaign_experiment_traffic_split_type as campaign_experiment_traffic_split_type,
)

__protobuf__: Any

class CampaignExperiment(proto.Message):
    resource_name: Any
    id: Any
    campaign_draft: Any
    name: Any
    description: Any
    traffic_split_percent: Any
    traffic_split_type: Any
    experiment_campaign: Any
    status: Any
    long_running_operation: Any
    start_date: Any
    end_date: Any



from typing import Any

import proto

__protobuf__: Any

class AssetFieldTypeEnum(proto.Message):
    class AssetFieldType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HEADLINE: int
        DESCRIPTION: int
        MANDATORY_AD_TEXT: int
        MARKETING_IMAGE: int
        MEDIA_BUNDLE: int
        YOUTUBE_VIDEO: int
        BOOK_ON_GOOGLE: int
        LEAD_FORM: int
        PROMOTION: int
        CALLOUT: int
        STRUCTURED_SNIPPET: int
        SITELINK: int



from typing import Any

import proto

__protobuf__: Any

class AdGroupBidModifierErrorEnum(proto.Message):
    class AdGroupBidModifierError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CRITERION_ID_NOT_SUPPORTED: int
        CANNOT_OVERRIDE_OPTED_OUT_CAMPAIGN_CRITERION_BID_MODIFIER: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    conversion_value_rule_set_status as conversion_value_rule_set_status,
    value_rule_set_attachment_type as value_rule_set_attachment_type,
    value_rule_set_dimension as value_rule_set_dimension,
)

__protobuf__: Any

class ConversionValueRuleSet(proto.Message):
    resource_name: Any
    id: Any
    conversion_value_rules: Any
    dimensions: Any
    owner_customer: Any
    attachment_type: Any
    campaign: Any
    status: Any



from typing import Any

import proto

__protobuf__: Any

class AffiliateLocationFeedRelationshipTypeEnum(proto.Message):
    class AffiliateLocationFeedRelationshipType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GENERAL_RETAILER: int



from typing import Any

import proto

__protobuf__: Any

class CallTrackingDisplayLocationEnum(proto.Message):
    class CallTrackingDisplayLocation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD: int
        LANDING_PAGE: int



from typing import Any

import proto

__protobuf__: Any

class BiddingStrategyErrorEnum(proto.Message):
    class BiddingStrategyError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_NAME: int
        CANNOT_CHANGE_BIDDING_STRATEGY_TYPE: int
        CANNOT_REMOVE_ASSOCIATED_STRATEGY: int
        BIDDING_STRATEGY_NOT_SUPPORTED: int
        INCOMPATIBLE_BIDDING_STRATEGY_AND_BIDDING_STRATEGY_GOAL_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class LabelErrorEnum(proto.Message):
    class LabelError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_APPLY_INACTIVE_LABEL: int
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION: int
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION: int
        EXCEEDED_LABEL_LIMIT_PER_TYPE: int
        INVALID_RESOURCE_FOR_MANAGER_LABEL: int
        DUPLICATE_NAME: int
        INVALID_LABEL_NAME: int
        CANNOT_ATTACH_LABEL_TO_DRAFT: int
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER: int



from typing import Any, Dict, Optional, Tuple, Union, overload

from typing_extensions import TypedDict

class _ConfigDataRequired(TypedDict):
    developer_token: str

class _ConfigDataOptional(TypedDict, total=False):
    endpoint: str
    http_proxy: str

class _ConfigDataParsedOptional(_ConfigDataOptional, total=False):
    login_customer_id: str
    linked_customer_id: str
    logging: Dict[str, Any]

class _ConfigDataUnparsedOptional(_ConfigDataOptional, total=False):
    login_customer_id: Union[int, str]
    linked_customer_id: Union[int, str]
    logging: Union[Dict[str, Any], str]

class _ConfigDataParsedRequired(_ConfigDataRequired):
    use_proto_plus: bool

class _ConfigDataUnparsedRequired(_ConfigDataRequired):
    use_proto_plus: Union[bool, str]

class _InstalledAppConfigDataRequired(TypedDict):
    client_id: str
    client_secret: str
    refresh_token: str

class _ServiceAccountConfigDataRequired(TypedDict):
    json_key_file_path: str
    impersonated_email: str

class _InstalledAppConfigData(
    _ConfigDataParsedRequired,
    _ConfigDataParsedOptional,
    _InstalledAppConfigDataRequired,
):
    pass

class _InstalledAppConfigDataUnparsed(
    _ConfigDataUnparsedRequired,
    _ConfigDataUnparsedOptional,
    _InstalledAppConfigDataRequired,
):
    pass

class _ServiceAccountConfigData(
    _ConfigDataParsedRequired,
    _ConfigDataParsedOptional,
    _ServiceAccountConfigDataRequired,
):
    pass

class _ServiceAccountConfigDataUnparsed(
    _ConfigDataUnparsedRequired,
    _ConfigDataUnparsedOptional,
    _ServiceAccountConfigDataRequired,
):
    pass

_ConfigData = Union[_InstalledAppConfigData, _ServiceAccountConfigData]
_ConfigDataUnparsed = Union[
    _InstalledAppConfigDataUnparsed, _ServiceAccountConfigDataUnparsed
]

def validate_dict(config_data: _ConfigData) -> None: ...
def validate_login_customer_id(login_customer_id: Optional[str]) -> None: ...
def validate_linked_customer_id(linked_customer_id: Optional[str]) -> None: ...
def load_from_yaml_file(path: Optional[str] = ...) -> _ConfigData: ...
@overload
def load_from_dict(
    config_dict: _InstalledAppConfigDataUnparsed,
) -> _InstalledAppConfigData: ...
@overload
def load_from_dict(
    config_dict: _ServiceAccountConfigDataUnparsed,
) -> _ServiceAccountConfigData: ...
def parse_yaml_document_to_dict(yaml_doc: bytes) -> _ConfigData: ...
def load_from_env() -> _ConfigData: ...
def get_oauth2_installed_app_keys() -> Tuple[str, str, str]: ...
def get_oauth2_service_account_keys() -> Tuple[str, str]: ...
@overload
def convert_login_customer_id_to_str(
    config_data: _InstalledAppConfigDataUnparsed,
) -> _InstalledAppConfigData: ...
@overload
def convert_login_customer_id_to_str(
    config_data: _ServiceAccountConfigDataUnparsed,
) -> _ServiceAccountConfigData: ...
@overload
def convert_linked_customer_id_to_str(
    config_data: _InstalledAppConfigDataUnparsed,
) -> _InstalledAppConfigData: ...
@overload
def convert_linked_customer_id_to_str(
    config_data: _ServiceAccountConfigDataUnparsed,
) -> _ServiceAccountConfigData: ...
def disambiguate_string_bool(value: Union[str, bool]) -> bool: ...



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAdGroupKeywordErrorEnum(proto.Message):
    class KeywordPlanAdGroupKeywordError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_KEYWORD_MATCH_TYPE: int
        DUPLICATE_KEYWORD: int
        KEYWORD_TEXT_TOO_LONG: int
        KEYWORD_HAS_INVALID_CHARS: int
        KEYWORD_HAS_TOO_MANY_WORDS: int
        INVALID_KEYWORD_TEXT: int
        NEGATIVE_KEYWORD_HAS_CPC_BID: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemSetStringFilterTypeEnum(proto.Message):
    class FeedItemSetStringFilterType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXACT: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanForecastIntervalEnum(proto.Message):
    class KeywordPlanForecastInterval(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NEXT_WEEK: int
        NEXT_MONTH: int
        NEXT_QUARTER: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    customer_pay_per_conversion_eligibility_failure_reason as customer_pay_per_conversion_eligibility_failure_reason,
)

__protobuf__: Any

class Customer(proto.Message):
    resource_name: Any
    id: Any
    descriptive_name: Any
    currency_code: Any
    time_zone: Any
    tracking_url_template: Any
    final_url_suffix: Any
    auto_tagging_enabled: Any
    has_partners_badge: Any
    manager: Any
    test_account: Any
    call_reporting_setting: Any
    conversion_tracking_setting: Any
    remarketing_setting: Any
    pay_per_conversion_eligibility_failure_reasons: Any
    optimization_score: Any
    optimization_score_weight: Any

class CallReportingSetting(proto.Message):
    call_reporting_enabled: Any
    call_conversion_reporting_enabled: Any
    call_conversion_action: Any

class ConversionTrackingSetting(proto.Message):
    conversion_tracking_id: Any
    cross_account_conversion_tracking_id: Any

class RemarketingSetting(proto.Message):
    google_global_site_tag: Any



from typing import Any

import proto

__protobuf__: Any

class PaymentModeEnum(proto.Message):
    class PaymentMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CLICKS: int
        CONVERSION_VALUE: int
        CONVERSIONS: int
        GUEST_STAY: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    custom_interest_member_type as custom_interest_member_type,
    custom_interest_status as custom_interest_status,
    custom_interest_type as custom_interest_type,
)

__protobuf__: Any

class CustomInterest(proto.Message):
    resource_name: Any
    id: Any
    status: Any
    name: Any
    type_: Any
    description: Any
    members: Any

class CustomInterestMember(proto.Message):
    member_type: Any
    parameter: Any



from typing import Any

import proto

__protobuf__: Any

class PricePlaceholderFieldEnum(proto.Message):
    class PricePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TYPE: int
        PRICE_QUALIFIER: int
        TRACKING_TEMPLATE: int
        LANGUAGE: int
        FINAL_URL_SUFFIX: int
        ITEM_1_HEADER: int
        ITEM_1_DESCRIPTION: int
        ITEM_1_PRICE: int
        ITEM_1_UNIT: int
        ITEM_1_FINAL_URLS: int
        ITEM_1_FINAL_MOBILE_URLS: int
        ITEM_2_HEADER: int
        ITEM_2_DESCRIPTION: int
        ITEM_2_PRICE: int
        ITEM_2_UNIT: int
        ITEM_2_FINAL_URLS: int
        ITEM_2_FINAL_MOBILE_URLS: int
        ITEM_3_HEADER: int
        ITEM_3_DESCRIPTION: int
        ITEM_3_PRICE: int
        ITEM_3_UNIT: int
        ITEM_3_FINAL_URLS: int
        ITEM_3_FINAL_MOBILE_URLS: int
        ITEM_4_HEADER: int
        ITEM_4_DESCRIPTION: int
        ITEM_4_PRICE: int
        ITEM_4_UNIT: int
        ITEM_4_FINAL_URLS: int
        ITEM_4_FINAL_MOBILE_URLS: int
        ITEM_5_HEADER: int
        ITEM_5_DESCRIPTION: int
        ITEM_5_PRICE: int
        ITEM_5_UNIT: int
        ITEM_5_FINAL_URLS: int
        ITEM_5_FINAL_MOBILE_URLS: int
        ITEM_6_HEADER: int
        ITEM_6_DESCRIPTION: int
        ITEM_6_PRICE: int
        ITEM_6_UNIT: int
        ITEM_6_FINAL_URLS: int
        ITEM_6_FINAL_MOBILE_URLS: int
        ITEM_7_HEADER: int
        ITEM_7_DESCRIPTION: int
        ITEM_7_PRICE: int
        ITEM_7_UNIT: int
        ITEM_7_FINAL_URLS: int
        ITEM_7_FINAL_MOBILE_URLS: int
        ITEM_8_HEADER: int
        ITEM_8_DESCRIPTION: int
        ITEM_8_PRICE: int
        ITEM_8_UNIT: int
        ITEM_8_FINAL_URLS: int
        ITEM_8_FINAL_MOBILE_URLS: int



from typing import Any

import proto

__protobuf__: Any

class ConversionLagBucketEnum(proto.Message):
    class ConversionLagBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LESS_THAN_ONE_DAY: int
        ONE_TO_TWO_DAYS: int
        TWO_TO_THREE_DAYS: int
        THREE_TO_FOUR_DAYS: int
        FOUR_TO_FIVE_DAYS: int
        FIVE_TO_SIX_DAYS: int
        SIX_TO_SEVEN_DAYS: int
        SEVEN_TO_EIGHT_DAYS: int
        EIGHT_TO_NINE_DAYS: int
        NINE_TO_TEN_DAYS: int
        TEN_TO_ELEVEN_DAYS: int
        ELEVEN_TO_TWELVE_DAYS: int
        TWELVE_TO_THIRTEEN_DAYS: int
        THIRTEEN_TO_FOURTEEN_DAYS: int
        FOURTEEN_TO_TWENTY_ONE_DAYS: int
        TWENTY_ONE_TO_THIRTY_DAYS: int
        THIRTY_TO_FORTY_FIVE_DAYS: int
        FORTY_FIVE_TO_SIXTY_DAYS: int
        SIXTY_TO_NINETY_DAYS: int



from typing import Any

import proto

__protobuf__: Any

class FeedItemErrorEnum(proto.Message):
    class FeedItemError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING: int
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM: int
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int
        KEY_ATTRIBUTES_NOT_FOUND: int
        INVALID_URL: int
        MISSING_KEY_ATTRIBUTES: int
        KEY_ATTRIBUTES_NOT_UNIQUE: int
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE: int
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE: int



from typing import Any

import proto

__protobuf__: Any

class ResourceCountLimitExceededErrorEnum(proto.Message):
    class ResourceCountLimitExceededError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ACCOUNT_LIMIT: int
        CAMPAIGN_LIMIT: int
        ADGROUP_LIMIT: int
        AD_GROUP_AD_LIMIT: int
        AD_GROUP_CRITERION_LIMIT: int
        SHARED_SET_LIMIT: int
        MATCHING_FUNCTION_LIMIT: int
        RESPONSE_ROW_LIMIT_EXCEEDED: int
        RESOURCE_LIMIT: int



from typing import Any

import proto

__protobuf__: Any

class AdvertisingChannelSubTypeEnum(proto.Message):
    class AdvertisingChannelSubType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEARCH_MOBILE_APP: int
        DISPLAY_MOBILE_APP: int
        SEARCH_EXPRESS: int
        DISPLAY_EXPRESS: int
        SHOPPING_SMART_ADS: int
        DISPLAY_GMAIL_AD: int
        DISPLAY_SMART_CAMPAIGN: int
        VIDEO_OUTSTREAM: int
        VIDEO_ACTION: int
        VIDEO_NON_SKIPPABLE: int
        APP_CAMPAIGN: int
        APP_CAMPAIGN_FOR_ENGAGEMENT: int
        LOCAL_CAMPAIGN: int
        SHOPPING_COMPARISON_LISTING_ADS: int
        SMART_CAMPAIGN: int
        VIDEO_SEQUENCE: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import geo_targeting_type as geo_targeting_type

__protobuf__: Any

class GeographicView(proto.Message):
    resource_name: Any
    location_type: Any
    country_criterion_id: Any



from typing import Any

import proto

__protobuf__: Any

class StringLengthErrorEnum(proto.Message):
    class StringLengthError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EMPTY: int
        TOO_SHORT: int
        TOO_LONG: int



from typing import Any

import proto

__protobuf__: Any

class ReachPlanErrorEnum(proto.Message):
    class ReachPlanError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NOT_FORECASTABLE_MISSING_RATE: int



from typing import Any

import proto

__protobuf__: Any

class YoutubeVideoRegistrationErrorEnum(proto.Message):
    class YoutubeVideoRegistrationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        VIDEO_NOT_FOUND: int
        VIDEO_NOT_ACCESSIBLE: int
        VIDEO_NOT_ELIGIBLE: int



from typing import Any

import proto

__protobuf__: Any

class CustomAudienceMemberTypeEnum(proto.Message):
    class CustomAudienceMemberType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD: int
        URL: int
        PLACE_CATEGORY: int
        APP: int



from typing import Any

import proto

__protobuf__: Any

class SimulationTypeEnum(proto.Message):
    class SimulationType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CPC_BID: int
        CPV_BID: int
        TARGET_CPA: int
        BID_MODIFIER: int
        TARGET_ROAS: int
        PERCENT_CPC_BID: int
        TARGET_IMPRESSION_SHARE: int
        BUDGET: int



from typing import Any

import proto

__protobuf__: Any

class UserListCrmDataSourceTypeEnum(proto.Message):
    class UserListCrmDataSourceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FIRST_PARTY: int
        THIRD_PARTY_CREDIT_BUREAU: int
        THIRD_PARTY_VOTER_FILE: int



from typing import Any

import proto

__protobuf__: Any

class CallPlaceholderFieldEnum(proto.Message):
    class CallPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PHONE_NUMBER: int
        COUNTRY_CODE: int
        TRACKED: int
        CONVERSION_TYPE_ID: int
        CONVERSION_REPORTING_STATE: int



from typing import Any

import proto

__protobuf__: Any

class AdStrengthEnum(proto.Message):
    class AdStrength(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        NO_ADS: int
        POOR: int
        AVERAGE: int
        GOOD: int
        EXCELLENT: int



from typing import Any

import proto

__protobuf__: Any

class StringFormatErrorEnum(proto.Message):
    class StringFormatError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ILLEGAL_CHARS: int
        INVALID_FORMAT: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetCampaignExperimentRequest(proto.Message):
    resource_name: Any

class MutateCampaignExperimentsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class CampaignExperimentOperation(proto.Message):
    update_mask: Any
    update: Any
    remove: Any

class MutateCampaignExperimentsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCampaignExperimentResult(proto.Message):
    resource_name: Any
    campaign_experiment: Any

class CreateCampaignExperimentRequest(proto.Message):
    customer_id: Any
    campaign_experiment: Any
    validate_only: Any

class CreateCampaignExperimentMetadata(proto.Message):
    campaign_experiment: Any

class GraduateCampaignExperimentRequest(proto.Message):
    campaign_experiment: Any
    campaign_budget: Any
    validate_only: Any

class GraduateCampaignExperimentResponse(proto.Message):
    graduated_campaign: Any

class PromoteCampaignExperimentRequest(proto.Message):
    campaign_experiment: Any
    validate_only: Any

class EndCampaignExperimentRequest(proto.Message):
    campaign_experiment: Any
    validate_only: Any

class ListCampaignExperimentAsyncErrorsRequest(proto.Message):
    resource_name: Any
    page_token: Any
    page_size: Any

class ListCampaignExperimentAsyncErrorsResponse(proto.Message):
    @property
    def raw_page(self): ...
    errors: Any
    next_page_token: Any



from typing import Any

import proto

__protobuf__: Any

class FunctionParsingErrorEnum(proto.Message):
    class FunctionParsingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NO_MORE_INPUT: int
        EXPECTED_CHARACTER: int
        UNEXPECTED_SEPARATOR: int
        UNMATCHED_LEFT_BRACKET: int
        UNMATCHED_RIGHT_BRACKET: int
        TOO_MANY_NESTED_FUNCTIONS: int
        MISSING_RIGHT_HAND_OPERAND: int
        INVALID_OPERATOR_NAME: int
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER: int
        NO_OPERANDS: int
        TOO_MANY_OPERANDS: int



from typing import Any

import proto

__protobuf__: Any

class TargetingDimensionEnum(proto.Message):
    class TargetingDimension(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD: int
        AUDIENCE: int
        TOPIC: int
        GENDER: int
        AGE_RANGE: int
        PLACEMENT: int
        PARENTAL_STATUS: int
        INCOME_RANGE: int



from typing import Any

import proto

__protobuf__: Any

class OfflineUserDataJobTypeEnum(proto.Message):
    class OfflineUserDataJobType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STORE_SALES_UPLOAD_FIRST_PARTY: int
        STORE_SALES_UPLOAD_THIRD_PARTY: int
        CUSTOMER_MATCH_USER_LIST: int
        CUSTOMER_MATCH_WITH_ATTRIBUTES: int



from typing import List, Optional, overload

from google.oauth2.credentials import Credentials as InstalledAppCredentials
from google.oauth2.service_account import Credentials as ServiceAccountCreds

from google.ads.googleads.config import (
    _InstalledAppConfigDataRequired,
    _ServiceAccountConfigDataRequired,
)

def get_installed_app_credentials(
    client_id: str,
    client_secret: str,
    refresh_token: str,
    http_proxy: Optional[str],
    token_uri: str = ...,
) -> InstalledAppCredentials: ...
def get_service_account_credentials(
    json_key_file_path: str,
    subject: str,
    http_proxy: Optional[str],
    scopes: List[str] = ...,
) -> ServiceAccountCreds: ...
@overload
def get_credentials(
    config_data: _InstalledAppConfigDataRequired,
) -> InstalledAppCredentials: ...
@overload
def get_credentials(
    config_data: _ServiceAccountConfigDataRequired,
) -> ServiceAccountCreds: ...



from typing import Any

import proto

__protobuf__: Any

class BiddingErrorEnum(proto.Message):
    class BiddingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED: int
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN: int
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE: int
        INVALID_BIDDING_STRATEGY_TYPE: int
        INVALID_BID: int
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE: int
        CONVERSION_TRACKING_NOT_ENABLED: int
        NOT_ENOUGH_CONVERSIONS: int
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY: int
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY: int
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE: int
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER: int
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA: int
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS: int
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS: int
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION: int
        BID_TOO_SMALL: int
        BID_TOO_BIG: int
        BID_TOO_MANY_FRACTIONAL_DIGITS: int
        INVALID_DOMAIN_NAME: int
        NOT_COMPATIBLE_WITH_PAYMENT_MODE: int
        NOT_COMPATIBLE_WITH_BUDGET_TYPE: int
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE: int
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET: int



from typing import Any

import proto

__protobuf__: Any

class AccountLinkStatusEnum(proto.Message):
    class AccountLinkStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ENABLED: int
        REMOVED: int
        REQUESTED: int
        PENDING_APPROVAL: int
        REJECTED: int
        REVOKED: int



from typing import Any

import proto

__protobuf__: Any

class MobileAppVendorEnum(proto.Message):
    class MobileAppVendor(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPLE_APP_STORE: int
        GOOGLE_APP_STORE: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import ad_asset as ad_asset
from google.ads.googleads.v7.enums.types import (
    call_conversion_reporting_state as call_conversion_reporting_state,
    display_ad_format_setting as display_ad_format_setting,
    legacy_app_install_ad_app_store as legacy_app_install_ad_app_store,
)

__protobuf__: Any

class TextAdInfo(proto.Message):
    headline: Any
    description1: Any
    description2: Any

class ExpandedTextAdInfo(proto.Message):
    headline_part1: Any
    headline_part2: Any
    headline_part3: Any
    description: Any
    description2: Any
    path1: Any
    path2: Any

class CallOnlyAdInfo(proto.Message):
    country_code: Any
    phone_number: Any
    business_name: Any
    headline1: Any
    headline2: Any
    description1: Any
    description2: Any
    call_tracked: Any
    disable_call_conversion: Any
    phone_number_verification_url: Any
    conversion_action: Any
    conversion_reporting_state: Any

class ExpandedDynamicSearchAdInfo(proto.Message):
    description: Any
    description2: Any

class HotelAdInfo(proto.Message): ...
class ShoppingSmartAdInfo(proto.Message): ...
class ShoppingProductAdInfo(proto.Message): ...

class ShoppingComparisonListingAdInfo(proto.Message):
    headline: Any

class GmailAdInfo(proto.Message):
    teaser: Any
    header_image: Any
    marketing_image: Any
    marketing_image_headline: Any
    marketing_image_description: Any
    marketing_image_display_call_to_action: Any
    product_images: Any
    product_videos: Any

class GmailTeaser(proto.Message):
    headline: Any
    description: Any
    business_name: Any
    logo_image: Any

class DisplayCallToAction(proto.Message):
    text: Any
    text_color: Any
    url_collection_id: Any

class ProductImage(proto.Message):
    product_image: Any
    description: Any
    display_call_to_action: Any

class ProductVideo(proto.Message):
    product_video: Any

class ImageAdInfo(proto.Message):
    pixel_width: Any
    pixel_height: Any
    image_url: Any
    preview_pixel_width: Any
    preview_pixel_height: Any
    preview_image_url: Any
    mime_type: Any
    name: Any
    media_file: Any
    data: Any
    ad_id_to_copy_image_from: Any

class VideoBumperInStreamAdInfo(proto.Message):
    companion_banner: Any

class VideoNonSkippableInStreamAdInfo(proto.Message):
    companion_banner: Any

class VideoTrueViewInStreamAdInfo(proto.Message):
    action_button_label: Any
    action_headline: Any
    companion_banner: Any

class VideoOutstreamAdInfo(proto.Message):
    headline: Any
    description: Any

class VideoTrueViewDiscoveryAdInfo(proto.Message):
    headline: Any
    description1: Any
    description2: Any

class VideoAdInfo(proto.Message):
    media_file: Any
    in_stream: Any
    bumper: Any
    out_stream: Any
    non_skippable: Any
    discovery: Any

class VideoResponsiveAdInfo(proto.Message):
    headlines: Any
    long_headlines: Any
    descriptions: Any
    call_to_actions: Any
    videos: Any
    companion_banners: Any

class ResponsiveSearchAdInfo(proto.Message):
    headlines: Any
    descriptions: Any
    path1: Any
    path2: Any

class LegacyResponsiveDisplayAdInfo(proto.Message):
    short_headline: Any
    long_headline: Any
    description: Any
    business_name: Any
    allow_flexible_color: Any
    accent_color: Any
    main_color: Any
    call_to_action_text: Any
    logo_image: Any
    square_logo_image: Any
    marketing_image: Any
    square_marketing_image: Any
    format_setting: Any
    price_prefix: Any
    promo_text: Any

class AppAdInfo(proto.Message):
    mandatory_ad_text: Any
    headlines: Any
    descriptions: Any
    images: Any
    youtube_videos: Any
    html5_media_bundles: Any

class AppEngagementAdInfo(proto.Message):
    headlines: Any
    descriptions: Any
    images: Any
    videos: Any

class LegacyAppInstallAdInfo(proto.Message):
    app_id: Any
    app_store: Any
    headline: Any
    description1: Any
    description2: Any

class ResponsiveDisplayAdInfo(proto.Message):
    marketing_images: Any
    square_marketing_images: Any
    logo_images: Any
    square_logo_images: Any
    headlines: Any
    long_headline: Any
    descriptions: Any
    youtube_videos: Any
    business_name: Any
    main_color: Any
    accent_color: Any
    allow_flexible_color: Any
    call_to_action_text: Any
    price_prefix: Any
    promo_text: Any
    format_setting: Any
    control_spec: Any

class LocalAdInfo(proto.Message):
    headlines: Any
    descriptions: Any
    call_to_actions: Any
    marketing_images: Any
    logo_images: Any
    videos: Any
    path1: Any
    path2: Any

class DisplayUploadAdInfo(proto.Message):
    display_upload_product_type: Any
    media_bundle: Any

class ResponsiveDisplayAdControlSpec(proto.Message):
    enable_asset_enhancements: Any
    enable_autogen_video: Any



from typing import Any

import proto

from google.ads.googleads.v7.resources.types import (
    customer_manager_link as customer_manager_link,
)

__protobuf__: Any

class GetCustomerManagerLinkRequest(proto.Message):
    resource_name: Any

class MutateCustomerManagerLinkRequest(proto.Message):
    customer_id: Any
    operations: Any
    validate_only: Any

class MoveManagerLinkRequest(proto.Message):
    customer_id: Any
    previous_customer_manager_link: Any
    new_manager: Any
    validate_only: Any

class CustomerManagerLinkOperation(proto.Message):
    update_mask: Any
    update: Any

class MutateCustomerManagerLinkResponse(proto.Message):
    results: Any

class MoveManagerLinkResponse(proto.Message):
    resource_name: Any

class MutateCustomerManagerLinkResult(proto.Message):
    resource_name: Any



from typing import Any

import proto
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetCustomerNegativeCriterionRequest(proto.Message):
    resource_name: Any

class MutateCustomerNegativeCriteriaRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class CustomerNegativeCriterionOperation(proto.Message):
    create: Any
    remove: Any

class MutateCustomerNegativeCriteriaResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateCustomerNegativeCriteriaResult(proto.Message):
    resource_name: Any
    customer_negative_criterion: Any



from typing import Any

import proto

__protobuf__: Any

class OfflineUserDataJobStatusEnum(proto.Message):
    class OfflineUserDataJobStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PENDING: int
        RUNNING: int
        SUCCESS: int
        FAILED: int



from typing import Any

import proto

__protobuf__: Any

class UserListDateRuleItemOperatorEnum(proto.Message):
    class UserListDateRuleItemOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EQUALS: int
        NOT_EQUALS: int
        BEFORE: int
        AFTER: int



from .base import (
    CampaignCriterionSimulationServiceTransport as CampaignCriterionSimulationServiceTransport,
)
from .grpc import (
    CampaignCriterionSimulationServiceGrpcTransport as CampaignCriterionSimulationServiceGrpcTransport,
)



from .base import (
    AssetFieldTypeViewServiceTransport as AssetFieldTypeViewServiceTransport,
)
from .grpc import (
    AssetFieldTypeViewServiceGrpcTransport as AssetFieldTypeViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ConversionAttributionEventTypeEnum(proto.Message):
    class ConversionAttributionEventType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        IMPRESSION: int
        INTERACTION: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    keyword_plan_common as keyword_plan_common,
)
from google.ads.googleads.v8.enums.types import (
    keyword_plan_keyword_annotation as keyword_plan_keyword_annotation,
)

__protobuf__: Any

class GenerateKeywordIdeasRequest(proto.Message):
    customer_id: Any
    language: Any
    geo_target_constants: Any
    include_adult_keywords: Any
    page_token: Any
    page_size: Any
    keyword_plan_network: Any
    keyword_annotation: Any
    aggregate_metrics: Any
    historical_metrics_options: Any
    keyword_and_url_seed: Any
    keyword_seed: Any
    url_seed: Any
    site_seed: Any

class KeywordAndUrlSeed(proto.Message):
    url: Any
    keywords: Any

class KeywordSeed(proto.Message):
    keywords: Any

class SiteSeed(proto.Message):
    site: Any

class UrlSeed(proto.Message):
    url: Any

class GenerateKeywordIdeaResponse(proto.Message):
    @property
    def raw_page(self): ...
    results: Any
    aggregate_metric_results: Any
    next_page_token: Any
    total_size: Any

class GenerateKeywordIdeaResult(proto.Message):
    text: Any
    keyword_idea_metrics: Any
    keyword_annotations: Any



from typing import Any

import proto

__protobuf__: Any

class DisplayAdFormatSettingEnum(proto.Message):
    class DisplayAdFormatSetting(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ALL_FORMATS: int
        NON_NATIVE: int
        NATIVE: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAdGroup(proto.Message):
    resource_name: Any
    keyword_plan_campaign: Any
    id: Any
    name: Any
    cpc_bid_micros: Any



from typing import Any

import proto

__protobuf__: Any

class MatchingFunctionContextTypeEnum(proto.Message):
    class MatchingFunctionContextType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FEED_ITEM_ID: int
        DEVICE_NAME: int
        FEED_ITEM_SET_ID: int



from typing import Any

import proto

__protobuf__: Any

class CampaignFeedErrorEnum(proto.Message):
    class CampaignFeedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CANNOT_CREATE_FOR_REMOVED_FEED: int
        CANNOT_CREATE_ALREADY_EXISTING_CAMPAIGN_FEED: int
        CANNOT_MODIFY_REMOVED_CAMPAIGN_FEED: int
        INVALID_PLACEHOLDER_TYPE: int
        MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE: int
        NO_EXISTING_LOCATION_CUSTOMER_FEED: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import offline_user_data as offline_user_data

__protobuf__: Any

class UploadUserDataRequest(proto.Message):
    customer_id: Any
    operations: Any
    customer_match_user_list_metadata: Any

class UserDataOperation(proto.Message):
    create: Any
    remove: Any

class UploadUserDataResponse(proto.Message):
    upload_date_time: Any
    received_operations_count: Any



from typing import Any

import proto

__protobuf__: Any

class FeedAttributeReferenceErrorEnum(proto.Message):
    class FeedAttributeReferenceError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_REFERENCE_REMOVED_FEED: int
        INVALID_FEED_NAME: int
        INVALID_FEED_ATTRIBUTE_NAME: int



from .base import (
    MobileAppCategoryConstantServiceTransport as MobileAppCategoryConstantServiceTransport,
)
from .grpc import (
    MobileAppCategoryConstantServiceGrpcTransport as MobileAppCategoryConstantServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class ValueRuleOperationEnum(proto.Message):
    class ValueRuleOperation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADD: int
        MULTIPLY: int
        SET: int



from typing import Any

import proto

__protobuf__: Any

class StructuredSnippetPlaceholderFieldEnum(proto.Message):
    class StructuredSnippetPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HEADER: int
        SNIPPETS: int



from typing import Any

import proto

__protobuf__: Any

class SearchTermTargetingStatusEnum(proto.Message):
    class SearchTermTargetingStatus(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ADDED: int
        EXCLUDED: int
        ADDED_EXCLUDED: int
        NONE: int



from typing import Any

import proto

__protobuf__: Any

class UserListClosingReasonEnum(proto.Message):
    class UserListClosingReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNUSED: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCompetitionLevelEnum(proto.Message):
    class KeywordPlanCompetitionLevel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOW: int
        MEDIUM: int
        HIGH: int



from typing import Any

import proto

__protobuf__: Any

class AssetLinkErrorEnum(proto.Message):
    class AssetLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PINNING_UNSUPPORTED: int
        UNSUPPORTED_FIELD_TYPE: int
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE: int
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE: int
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE: int
        IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE: int
        INVALID_PINNED_FIELD: int
        MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION: int
        YOUTUBE_VIDEO_REMOVED: int
        YOUTUBE_VIDEO_TOO_LONG: int
        YOUTUBE_VIDEO_TOO_SHORT: int
        INVALID_STATUS: int



import abc
import typing
from typing import Any

from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v8.services.types import reach_plan_service

class ReachPlanServiceTransport(metaclass=abc.ABCMeta):
    AUTH_SCOPES: Any
    def __init__(
        self,
        *,
        host: str = ...,
        credentials: ga_credentials.Credentials = ...,
        client_info: gapic_v1.client_info.ClientInfo = ...
    ) -> None: ...
    @property
    def list_plannable_locations(
        self,
    ) -> typing.Callable[
        [reach_plan_service.ListPlannableLocationsRequest],
        reach_plan_service.ListPlannableLocationsResponse,
    ]: ...
    @property
    def list_plannable_products(
        self,
    ) -> typing.Callable[
        [reach_plan_service.ListPlannableProductsRequest],
        reach_plan_service.ListPlannableProductsResponse,
    ]: ...
    @property
    def generate_product_mix_ideas(
        self,
    ) -> typing.Callable[
        [reach_plan_service.GenerateProductMixIdeasRequest],
        reach_plan_service.GenerateProductMixIdeasResponse,
    ]: ...
    @property
    def generate_reach_forecast(
        self,
    ) -> typing.Callable[
        [reach_plan_service.GenerateReachForecastRequest],
        reach_plan_service.GenerateReachForecastResponse,
    ]: ...



from typing import Any

import proto

__protobuf__: Any

class PolicyValidationParameterErrorEnum(proto.Message):
    class PolicyValidationParameterError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNSUPPORTED_AD_TYPE_FOR_IGNORABLE_POLICY_TOPICS: int
        UNSUPPORTED_AD_TYPE_FOR_EXEMPT_POLICY_VIOLATION_KEYS: int
        CANNOT_SET_BOTH_IGNORABLE_POLICY_TOPICS_AND_EXEMPT_POLICY_VIOLATION_KEYS: int
